(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     69165,       1962]
NotebookOptionsPosition[     64625,       1810]
NotebookOutlinePosition[     64985,       1826]
CellTagsIndexPosition[     64942,       1823]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook shows how ",
 StyleBox["SpinDynamica",
  FontSlant->"Italic"],
 " may be used to calculate 2D spectra in simple cases. A fully general \
implementation in ",
 StyleBox["SpinDynamica",
  FontSlant->"Italic"],
 " has not been done yet, but these routines may be of use and interest. "
}], "Text",
 CellChangeTimes->{{3.678699230474339*^9, 3.678699280908536*^9}}],

Cell[CellGroupData[{

Cell["2D peak and spectrum routines", "Subchapter",
 CellChangeTimes->{{3.678524909087391*^9, 3.6785249145874863`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.678523305029883*^9, 3.678523311105096*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 2.14.2 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.678699367649239*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"$Version", "\[IndentingNewLine]", "$SpinDynamicaVersion"}], \
"Input",
 CellChangeTimes->{{3.678696333716206*^9, 3.678696363703849*^9}}],

Cell[BoxData["\<\"10.4.1 for Mac OS X x86 (64-bit) (April 11, 2016)\"\>"], \
"Output",
 CellChangeTimes->{{3.6786963493611298`*^9, 3.678696364520743*^9}, 
   3.678697555418603*^9, 3.678699226844183*^9, 3.6786993018911867`*^9, 
   3.678699369974183*^9}],

Cell[BoxData["\<\"SpinDynamica version 2.14.2\"\>"], "Output",
 CellChangeTimes->{{3.6786963493611298`*^9, 3.678696364520743*^9}, 
   3.678697555418603*^9, 3.678699226844183*^9, 3.6786993018911867`*^9, 
   3.6786993699805927`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Peak2D: a 2D Lorentzian peak function", "Subsection",
 CellChangeTimes->{{3.6785249190366583`*^9, 3.678524922811306*^9}, {
   3.67869641704956*^9, 3.67869642458637*^9}, 3.67869650140376*^9}],

Cell[TextData[{
 "spectral function of a 2D spectral peak (complex Lorentzian) with given \
amplitude, frequency coordinates, and linewidth parameters. The option \
Peakwidth controls the linewidth in one or two dimensions. Frequency \
coordinates are in rad\[NonBreakingSpace]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["s", 
     RowBox[{"-", "1"}]], "."}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.6785379282041197`*^9, 3.6785379842404423`*^9}, {
  3.678696516422702*^9, 3.6786965367283363`*^9}, {3.678696579516568*^9, 
  3.6786966101152287`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "Peak2D", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"Peakwidth", "\[Rule]", 
     RowBox[{"2", "\[Pi]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.678696538919961*^9, 3.678696575890298*^9}, 
   3.678696619542081*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Peak2D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", 
       RowBox[{"{", 
        RowBox[{"\[Omega]1p_", ",", "\[Omega]2p_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]1_", ",", "\[Lambda]2_"}], "}"}]}], "}"}], ",", 
     "opts___Rule"}], "]"}], ":=", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Omega]1", ",", "\[Omega]2"}], "}"}], ",", 
     RowBox[{"a", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]1", "+", 
          RowBox[{"I", " ", 
           RowBox[{"(", 
            RowBox[{"\[Omega]1", "-", "\[Omega]1p"}], ")"}]}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Lambda]2", "+", 
          RowBox[{"I", " ", 
           RowBox[{"(", 
            RowBox[{"\[Omega]2", "-", "\[Omega]2p"}], ")"}]}]}], ")"}]}], 
       ")"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.678523447568563*^9, 3.6785235899087954`*^9}, {
   3.678523621141608*^9, 3.6785237364901457`*^9}, {3.678523799512631*^9, 
   3.678523801640448*^9}, {3.678524168531907*^9, 3.678524175234785*^9}, {
   3.6785243684160233`*^9, 3.6785243716795177`*^9}, {3.6785245479732313`*^9, 
   3.6785245745789423`*^9}, 3.678696506053536*^9, {3.678696627214192*^9, 
   3.678696630116444*^9}, 3.678696684005723*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Peak2D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", 
       RowBox[{"{", 
        RowBox[{"\[Omega]1p_", ",", "\[Omega]2p_"}], "}"}], ",", 
       RowBox[{"\[Lambda]", ":", 
        RowBox[{"Except", "[", "_List", "]"}]}]}], "}"}], ",", 
     "opts___Rule"}], "]"}], ":=", 
   RowBox[{"Peak2D", "[", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]1p", ",", "\[Omega]2p"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Lambda]", ",", "\[Lambda]"}], "}"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6785243814953127`*^9, 3.6785244194130774`*^9}, {
   3.678524583666934*^9, 3.678524591578619*^9}, {3.678696507830535*^9, 
   3.678696509439171*^9}, {3.678696638375021*^9, 3.678696641119027*^9}, 
   3.678696686041044*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Peak2D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", 
       RowBox[{"{", 
        RowBox[{"\[Omega]1p_", ",", "\[Omega]2p_"}], "}"}]}], "}"}], ",", 
     "opts___Rule"}], "]"}], ":=", 
   RowBox[{"Peak2D", "[", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]1p", ",", "\[Omega]2p"}], "}"}], ",", 
      RowBox[{
       RowBox[{"Peakwidth", "/.", 
        RowBox[{"{", "opts", "}"}]}], "/.", 
       RowBox[{"Options", "[", "Peak2D", "]"}]}]}], " ", "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.678524428262681*^9, 3.678524445716853*^9}, {
  3.678524597645698*^9, 3.6785246058838882`*^9}, {3.6786965110706167`*^9, 
  3.678696512161312*^9}, {3.678696659086672*^9, 3.678696688178542*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Spectrum2D: a 2D spectral function", "Subsection",
 CellChangeTimes->{{3.6785249190366583`*^9, 3.678524930800213*^9}, {
  3.678696441270348*^9, 3.6786964496969347`*^9}, {3.6786967155167418`*^9, 
  3.678696722660144*^9}}],

Cell["\<\
generates a 2D spectral function from a list of peaks. The option Symmetrize \
can be used to control whether STATES/TPPI data processing is assumed. \
\>", "Text",
 CellChangeTimes->{{3.6785379592241173`*^9, 3.678537975512724*^9}, {
  3.678696462804102*^9, 3.6786964906813183`*^9}, {3.6786974810026293`*^9, 
  3.678697481238126*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "Spectrum2D", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Symmetrize", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"Peakwidth", "\[Rule]", 
      RowBox[{"2", "\[Pi]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.678696493976462*^9, 3.678696495207387*^9}, {
  3.678696727867771*^9, 3.678696730805419*^9}, {3.678696853692053*^9, 
  3.678696868721588*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Spectrum2D", "[", 
     RowBox[{"peaks_List", ",", "opts___Rule"}], "]"}], "/;", 
    RowBox[{"!", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Symmetrize", "/.", 
        RowBox[{"{", "opts", "}"}]}], "/.", 
       RowBox[{"Options", "[", "Spectrum2D", "]"}]}], ")"}]}]}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Omega]1", ",", "\[Omega]2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Evaluate", "@", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Plus", "@@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Peak2D", "[", 
             RowBox[{"#", ",", 
              RowBox[{"SimplifyRules", "[", 
               RowBox[{"opts", ",", 
                RowBox[{"Sequence", "@@", 
                 RowBox[{"Options", "[", "Spectrum2D", "]"}]}]}], "]"}]}], 
             "]"}], "[", 
            RowBox[{"\[Omega]1", ",", "\[Omega]2"}], "]"}], "&"}], "/@", 
          "peaks"}], ")"}]}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.678524272284181*^9, 3.678524337678046*^9}, {
   3.6785244690450983`*^9, 3.678524541732758*^9}, {3.678524619212943*^9, 
   3.678524627061306*^9}, {3.67852469381719*^9, 3.6785246958650084`*^9}, {
   3.678524768872984*^9, 3.678524774087358*^9}, {3.678525092818788*^9, 
   3.678525094681164*^9}, {3.678696877735265*^9, 3.678697012217951*^9}, 
   3.678697456321289*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Spectrum2D", "[", 
     RowBox[{"peaks_List", ",", "opts___Rule"}], "]"}], "/;", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Symmetrize", "/.", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "Spectrum2D", "]"}]}], ")"}]}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Omega]1", ",", "\[Omega]2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Spectrum2D", "[", 
         RowBox[{"peaks", ",", 
          RowBox[{"Symmetrize", "\[Rule]", "False"}], ",", "opts"}], "]"}], 
        "[", 
        RowBox[{"\[Omega]1", ",", "\[Omega]2"}], "]"}], "+", 
       RowBox[{
        RowBox[{"Spectrum2D", "[", 
         RowBox[{"peaks", ",", 
          RowBox[{"Symmetrize", "\[Rule]", "False"}], ",", "opts"}], "]"}], 
        "[", 
        RowBox[{
         RowBox[{"-", "\[Omega]1"}], ",", "\[Omega]2"}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.67869702503505*^9, 3.67869709411928*^9}, {
  3.6786976785677147`*^9, 3.678697687455196*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Peaks2D: generate a set of 2D peaks for a typical experimental procedure\
\>", "Subsection",
 CellChangeTimes->{{3.6785249190366583`*^9, 3.678524922811306*^9}, 
   3.6785335883871527`*^9, {3.6786971351729727`*^9, 3.6786971815779657`*^9}}],

Cell["\<\
peaks2D computes the set of 2D peaks for a given initial density operator, \
excitation sequence, mixing sequence, and observable operator, assuming an \
evolution background H0 (during both t1 and t2 intervals). The output is a \
list of the form {{amp,{\[Omega]1,\[Omega]2}}..} where each peak has a \
defined complex amplitude and 2D frequency coordinates. This list of peaks \
may be converted to a 2D spectral function using Spectrum2D. \
\>", "Text",
 CellChangeTimes->{{3.6785336489760113`*^9, 3.678533777886104*^9}, {
   3.678534856220304*^9, 3.678534879001108*^9}, 3.678697544963174*^9}],

Cell["\<\
At this point this routine is not completely general. For example it cannot \
handle a mixing superoperator. \
\>", "Text",
 CellChangeTimes->{{3.678538030814535*^9, 3.678538053060151*^9}}],

Cell["\<\
The theoretical background for this is found in, for example, the \
Ernst-Bodenhausen-Wokaun book\
\>", "Text",
 CellChangeTimes->{{3.67853807408455*^9, 3.678538091082815*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Peaks2D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Rho]0_", ",", "Exc_", ",", "Mix_", ",", "Qobs_"}], "}"}], 
     ",", "H0_", ",", "opts___Rule"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "eigenbasis", ",", "\[Rho]1mat", ",", "Vmat", ",", "Vmatadj", ",", 
       "Qobsmat", ",", "Qobsmatadj", ",", "n", ",", "evals", ",", 
       "\[Omega]mat"}], "}"}], ",", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"BasisDimension", "[", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Off", "[", 
        StyleBox[
         RowBox[{"DefineBasis", "::", "defined"}], "MessageName"], 
        StyleBox["]", "MessageName"]}], 
       StyleBox[";", "MessageName"], 
       StyleBox["\[IndentingNewLine]", "MessageName"], 
       StyleBox[
        RowBox[{"Off", "[", 
         RowBox[{"N", "::", "meprec"}], "]"}], "MessageName"], 
       StyleBox[";", "MessageName"], "\[IndentingNewLine]", 
       RowBox[{"DefineBasis", "[", 
        RowBox[{"eigenbasis", ",", 
         RowBox[{"BasisKets", "[", 
          RowBox[{"Eigenbasis", "[", "H0", "]"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Rho]1mat", "=", 
        RowBox[{"MatrixRepresentation", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"NPropagate", "[", 
            RowBox[{"Exc", ",", 
             RowBox[{"EvolutionBackground", "\[Rule]", "H0"}]}], "]"}], "[", 
           "\[Rho]0", "]"}], ",", "eigenbasis"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Vmat", "=", 
        RowBox[{"MatrixRepresentation", "[", 
         RowBox[{
          RowBox[{"NPropagationOperator", "[", 
           RowBox[{"Mix", ",", 
            RowBox[{"EvolutionBackground", "\[Rule]", "H0"}]}], "]"}], ",", 
          "eigenbasis"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Vmatadj", "=", 
        RowBox[{"ConjugateTranspose", "[", "Vmat", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Qobsmat", "=", 
        RowBox[{"MatrixRepresentation", "[", 
         RowBox[{"Qobs", ",", "eigenbasis"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Qobsmatadj", "=", 
        RowBox[{"ConjugateTranspose", "[", "Qobsmat", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"evals", "=", 
        RowBox[{"Normal", "@", 
         RowBox[{"Diagonal", "[", 
          RowBox[{"MatrixRepresentation", "[", 
           RowBox[{"H0", ",", "eigenbasis"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Omega]mat", "=", 
        RowBox[{"-", 
         RowBox[{"Outer", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"#1", "-", "#2"}], ")"}], "&"}], ",", "evals", ",", 
           "evals"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Select", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"N", "@", 
            RowBox[{"Table", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Rho]1mat", "\[LeftDoubleBracket]", 
                  RowBox[{"r", ",", "s"}], "\[RightDoubleBracket]"}], "*", 
                 RowBox[{"Vmat", "\[LeftDoubleBracket]", 
                  RowBox[{"t", ",", "r"}], "\[RightDoubleBracket]"}], "*", 
                 RowBox[{"Vmatadj", "\[LeftDoubleBracket]", 
                  RowBox[{"s", ",", "u"}], "\[RightDoubleBracket]"}], "*", 
                 RowBox[{"Qobsmatadj", "\[LeftDoubleBracket]", 
                  RowBox[{"u", ",", "t"}], "\[RightDoubleBracket]"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Omega]mat", "\[LeftDoubleBracket]", 
                   RowBox[{"r", ",", "s"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"\[Omega]mat", "\[LeftDoubleBracket]", 
                   RowBox[{"t", ",", "u"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"r", ",", "1", ",", "n"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"s", ",", "1", ",", "n"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "1", ",", "n"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"u", ",", "1", ",", "n"}], "}"}]}], 
             "\[IndentingNewLine]", "]"}]}], ",", "3"}], 
          "\[IndentingNewLine]", "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Chop", "[", 
             RowBox[{"First", "[", "#", "]"}], "]"}], "\[NotEqual]", "0"}], 
           ")"}], "&"}]}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", ")"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.67853359545712*^9, 3.67853364293888*^9}, {
   3.67853378287253*^9, 3.6785341603149433`*^9}, {3.67853432854817*^9, 
   3.678534351171612*^9}, 3.678534457154009*^9, {3.678534562041259*^9, 
   3.678534618833062*^9}, {3.678534702334587*^9, 3.6785347039103394`*^9}, {
   3.678534769230618*^9, 3.67853476970107*^9}, 3.6786971621092367`*^9, {
   3.678697261422421*^9, 3.678697286036807*^9}, 3.678698507810021*^9, {
   3.678699344642727*^9, 3.678699350457868*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example calculations", "Subchapter",
 CellChangeTimes->{{3.678524909087391*^9, 3.6785249145874863`*^9}, {
   3.678530069846006*^9, 3.678530074748612*^9}, 3.678696386111936*^9}],

Cell[CellGroupData[{

Cell["set default plot options", "Subsection",
 CellChangeTimes->{{3.678535150699234*^9, 3.678535155146798*^9}, {
  3.67853831825762*^9, 3.678538324063386*^9}, {3.678698697439617*^9, 
  3.678698698474751*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Plot3D", ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
    RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"LightYellow", ",", 
       RowBox[{"Specularity", "[", 
        RowBox[{"White", ",", "50"}], "]"}]}], "]"}]}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.678538331147006*^9, 3.678538355104122*^9}, {
  3.678698356562006*^9, 3.678698381579534*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["peaks", "Subsection",
 CellChangeTimes->{{3.6785249190366583`*^9, 3.678524938627336*^9}, 
   3.678525225726664*^9, {3.678697571634161*^9, 3.678697578293442*^9}, {
   3.678698007815181*^9, 3.6786980294596167`*^9}, {3.6786986897129087`*^9, 
   3.678698692590763*^9}, {3.678699148540597*^9, 3.678699149314724*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Spectrum2D", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"2", "\[Pi]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "3"}], "}"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"2", "\[Pi]", 
        RowBox[{"{", 
         RowBox[{"15", ",", 
          RowBox[{"-", "5"}]}], "}"}]}]}], "}"}]}], "}"}], "]"}], "[", 
  RowBox[{"\[Omega]1", ",", "\[Omega]2"}], "]"}]], "Input",
 CellChangeTimes->{{3.678524987019495*^9, 3.678525002561862*^9}, 
   3.678525118406477*^9, {3.6786975820510283`*^9, 3.678697606363735*^9}, {
   3.678697722712619*^9, 3.678697748982787*^9}, 3.678697783893566*^9}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"2", "\[Pi]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12"}], ",", "5"}], "}"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"2", "\[Pi]", 
            RowBox[{"{", 
             RowBox[{"12", ",", "5"}], "}"}]}]}], "}"}]}], "}"}], "]"}], "[", 
      
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678524642317128*^9, 3.678524664601783*^9}, {
  3.678524854560987*^9, 3.678524878492941*^9}, {3.6785251455923157`*^9, 
  3.67852514741464*^9}, {3.678538006907535*^9, 3.67853801079478*^9}, {
  3.67869761292446*^9, 3.678697624583008*^9}, {3.678697740220482*^9, 
  3.678697774272793*^9}, {3.678697883953771*^9, 3.6786979061809063`*^9}, {
  3.678698187200242*^9, 3.6786981982701273`*^9}, {3.678698270131679*^9, 
  3.678698329772707*^9}, {3.678698373851919*^9, 3.67869837439079*^9}}],

Cell[BoxData[
 RowBox[{"ContourPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"2", "\[Pi]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "12"}], ",", "5"}], "}"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"2", "\[Pi]", 
             RowBox[{"{", 
              RowBox[{"12", ",", "5"}], "}"}]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Symmetrize", "\[Rule]", "False"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678697948528763*^9, 3.678697990579632*^9}, {
  3.6786982204444437`*^9, 3.678698229218369*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"2", "\[Pi]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "12"}], ",", "5"}], "}"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"2", "\[Pi]", 
             RowBox[{"{", 
              RowBox[{"12", ",", "5"}], "}"}]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Symmetrize", "\[Rule]", "True"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678524642317128*^9, 3.678524664601783*^9}, {
  3.678524854560987*^9, 3.678524878492941*^9}, {3.6785251455923157`*^9, 
  3.67852514741464*^9}, {3.678538006907535*^9, 3.67853801079478*^9}, {
  3.67869761292446*^9, 3.678697624583008*^9}, {3.678697740220482*^9, 
  3.678697774272793*^9}, {3.678697883953771*^9, 3.678697928230978*^9}, {
  3.678698237612404*^9, 3.678698238499771*^9}}],

Cell[BoxData[
 RowBox[{"ContourPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"2", "\[Pi]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "12"}], ",", "5"}], "}"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"2", "\[Pi]", 
             RowBox[{"{", 
              RowBox[{"12", ",", "5"}], "}"}]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Symmetrize", "\[Rule]", "True"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678697948528763*^9, 3.678697973670578*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2Q spectroscopy in an AB spin system", "Subsection",
 CellChangeTimes->{{3.678535150699234*^9, 3.678535155146798*^9}, {
  3.678535197035143*^9, 3.678535200529313*^9}, {3.67869805650703*^9, 
  3.678698064065143*^9}}],

Cell[CellGroupData[{

Cell["setup", "Subsubsection",
 CellChangeTimes->{{3.6786984592282057`*^9, 3.6786984830676327`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SetSpinSystem", "[", "2", "]"}]}], "Input",
 CellChangeTimes->{{3.678530076322297*^9, 3.6785300829884043`*^9}, {
  3.678530117852811*^9, 3.678530122532709*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.678530123150388*^9, 3.678532054248698*^9, 
  3.678534179784376*^9, 3.678538139886883*^9, 3.678698067427342*^9, 
  3.6786993172337933`*^9, 3.6786993824451303`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"BasisLabels\\\", \
\\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \\\"]\\\"}]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.678530123150388*^9, 3.678532054248698*^9, 
  3.678534179784376*^9, 3.678538139886883*^9, 3.678698067427342*^9, 
  3.6786993172337933`*^9, 3.6786993826139727`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parameters", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[CapitalOmega]1", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "60"}]}], ",", " ", 
    RowBox[{"\[CapitalOmega]2", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", 
      RowBox[{"(", 
       RowBox[{"-", "10"}], ")"}]}]}], ",", " ", 
    RowBox[{"J", "\[Rule]", "20"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.678530141839306*^9, 3.678530190341776*^9}, {
  3.67853038673897*^9, 3.678530401591988*^9}, {3.678533151617073*^9, 
  3.678533169396323*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalOmega]1", "\[Rule]", 
    RowBox[{"120", " ", "\[Pi]"}]}], ",", 
   RowBox[{"\[CapitalOmega]2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "20"}], " ", "\[Pi]"}]}], ",", 
   RowBox[{"J", "\[Rule]", "20"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.678530190919232*^9, {3.678530387321327*^9, 3.678530409732147*^9}, 
   3.6785320545887403`*^9, {3.678533153005501*^9, 3.678533172777575*^9}, 
   3.678534189120825*^9, 3.678538140041078*^9, 3.678698072215176*^9, 
   3.678699317423936*^9, 3.67869938264977*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"H0", "[", "opts___Rule", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalOmega]1", " ", 
        RowBox[{"opI", "[", 
         RowBox[{"1", ",", "\"\<z\>\""}], "]"}]}], "+", 
       RowBox[{"\[CapitalOmega]2", " ", 
        RowBox[{"opI", "[", 
         RowBox[{"2", ",", "\"\<z\>\""}], "]"}]}], "+", 
       RowBox[{"2", "\[Pi]", " ", "J", " ", 
        RowBox[{
         RowBox[{"opI", "[", "1", "]"}], ".", 
         RowBox[{"opI", "[", "2", "]"}]}]}]}], ")"}], "/.", 
     RowBox[{"{", "opts", "}"}]}], "/.", "parameters"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6785301257172623`*^9, 3.678530126691823*^9}, {
  3.678530194829555*^9, 3.67853030976906*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H0", "[", "]"}]], "Input",
 CellChangeTimes->{{3.678530312313595*^9, 3.678530313538426*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"40", " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "x"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "x"}]],
        DisplayForm]}],
      DisplayForm], "+", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "y"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "y"}]],
        DisplayForm]}],
      DisplayForm], "+", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "z"}]],
        DisplayForm]}],
      DisplayForm]}], ")"}]}], "+", 
  RowBox[{"120", " ", "\[Pi]", " ", 
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm]}], "-", 
  RowBox[{"20", " ", "\[Pi]", " ", 
   TagBox[
    SubscriptBox["I", 
     RowBox[{"2", "z"}]],
    DisplayForm]}]}]], "Output",
 CellChangeTimes->{
  3.678530314069179*^9, 3.6785304098138027`*^9, 3.678532054662485*^9, {
   3.678533157606947*^9, 3.6785331728351603`*^9}, 3.6785341922233067`*^9, 
   3.6785381401092043`*^9, 3.678698072307716*^9, 3.678699317483736*^9, 
   3.678699382712516*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["1D spectrum", "Subsubsection",
 CellChangeTimes->{{3.6786984592282057`*^9, 3.6786984631544657`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "@", 
  RowBox[{"Re", "@", 
   RowBox[{"FT", "@", 
    RowBox[{"Signal1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "\[Pi]", " ", "300"}], ",", "\"\<1k\>\""}], "}"}], 
       "}"}], ",", 
      RowBox[{"H0", "[", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.678530317361528*^9, 3.678530349664948*^9}, {
  3.6785304063037977`*^9, 3.6785304065274563`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetOperatorBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the operator basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ShiftAndZOperatorBasis\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"Sorted\\\", \\\"\
\[Rule]\\\", \\\"CoherenceOrder\\\"}]}], \\\"]\\\"}]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{{3.6785303354272537`*^9, 3.678530350192502*^9}, {
   3.678530390076488*^9, 3.678530409998979*^9}, 3.6785320549630136`*^9, {
   3.6785331579784822`*^9, 3.678533173198732*^9}, 3.678534195160533*^9, 
   3.67853814042733*^9, 3.678698076654004*^9, 3.678699320874083*^9, 
   3.678699386119582*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Double-Quantum 2D spectrum", "Subsubsection",
 CellChangeTimes->{{3.678535150699234*^9, 3.678535155146798*^9}, {
  3.678698471164547*^9, 3.678698471862444*^9}}],

Cell["\<\
assumes a classic \
\[OpenCurlyDoubleQuote]INADEQUATE\[CloseCurlyDoubleQuote]-style excitation \
sequence and single pulse mixing\
\>", "Text",
 CellChangeTimes->{{3.678538148397056*^9, 3.678538168890679*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]", "=", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"4", "J"}], ")"}]}], "/.", "parameters"}]}]], "Input",
 CellChangeTimes->{{3.678530776791782*^9, 3.6785307846284847`*^9}}],

Cell[BoxData[
 FractionBox["1", "80"]], "Output",
 CellChangeTimes->{3.678530785361415*^9, 3.678531536925021*^9, 
  3.678532086969067*^9, 3.678533190939745*^9, 3.678535190320512*^9, 
  3.678535768449749*^9, 3.678538174461632*^9, 3.6786984169100323`*^9, 
  3.678699326434284*^9, 3.678699390260717*^9}]
}, Open  ]],

Cell["ignore the numerical warnings upon setting up the eigenbasis", "Text",
 CellChangeTimes->{{3.6786991831216383`*^9, 3.678699196936811*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Rho]ini", "=", 
   RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Exc", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RotationSuperoperator", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<x\>\""}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\[Tau]"}], "}"}], ",", 
     RowBox[{"RotationSuperoperator", "[", 
      RowBox[{"{", 
       RowBox[{"\[Pi]", ",", "\"\<x\>\""}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\[Tau]"}], "}"}], ",", 
     RowBox[{"RotationSuperoperator", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<x\>\""}], "}"}], "]"}], ",", 
     RowBox[{"CoherenceOrderFiltrationSuperoperator", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], "]"}]}], "\[IndentingNewLine]",
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mix", "=", 
   RowBox[{"RotationSuperoperator", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<y\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qobs", "=", 
   RowBox[{
    RowBox[{"-", "2"}], "I", "  ", 
    RowBox[{"opI", "[", "\"\<-\>\"", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"peaks", "=", 
  RowBox[{"Peaks2D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Rho]ini", ",", "Exc", ",", "Mix", ",", "Qobs"}], "}"}], ",", 
    RowBox[{"H0", "[", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.678534229826165*^9, 3.6785343151928387`*^9}, {
   3.6785343858768663`*^9, 3.678534397795134*^9}, 3.678534500810471*^9, {
   3.678534653302196*^9, 3.678534673492441*^9}, {3.678534796293148*^9, 
   3.6785348072113533`*^9}, {3.678534936547591*^9, 3.6785350265767193`*^9}, 
   3.678698425558075*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CheckBasis", "::", "orthonormal"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"State basis is orthonormal.\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.6786984264874897`*^9, 3.6786985150491667`*^9, 
  3.678699326559497*^9, 3.678699390596221*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.3583801104666254`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "314.1592653589793`"}], ",", "448.6228832061863`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.6298745437125661`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "314.1592653589793`"}], ",", 
       RowBox[{"-", "8.799911703615294`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.3583801104666254`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "314.1592653589793`"}], ",", 
       RowBox[{"-", "134.46361784720702`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.6298745437125661`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "314.1592653589793`"}], ",", "322.95917706259456`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.3583801104666254`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"314.1592653589793`", ",", "448.6228832061863`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.6298745437125661`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"314.1592653589793`", ",", 
       RowBox[{"-", "8.799911703615294`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.3583801104666254`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"314.1592653589793`", ",", 
       RowBox[{"-", "134.46361784720702`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.6298745437125661`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"314.1592653589793`", ",", "322.95917706259456`"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.678534298303314*^9, 3.678534316620743*^9}, 
   3.678534361538315*^9, 3.678534399135789*^9, 3.678534464778421*^9, 
   3.678534502226513*^9, {3.678534625393993*^9, 3.678534674599235*^9}, 
   3.678534715497238*^9, {3.67853478307686*^9, 3.6785348088037977`*^9}, 
   3.678535020475525*^9, 3.678535769470697*^9, 3.678538175641939*^9, {
   3.678698420353362*^9, 3.6786984276873617`*^9}, 3.678698515853127*^9, 
   3.678699327771785*^9, 3.6786993914611692`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.67853818387987*^9, 3.6785381867110653`*^9}}],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{3.6785381872709637`*^9, 3.6786985194996367`*^9, 
  3.678699327808798*^9, 3.678699391530424*^9}]
}, Open  ]],

Cell["\<\
This shows there are 8 peaks in the 2D spectrum. These have phase-twist \
lineshapes. \
\>", "Text",
 CellChangeTimes->{{3.6785350317669783`*^9, 3.6785350559024687`*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", "peaks", "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", 
     RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", 
     RowBox[{"-", "100"}], ",", "100"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678524642317128*^9, 3.678524664601783*^9}, {
   3.678524854560987*^9, 3.678524878492941*^9}, {3.6785251455923157`*^9, 
   3.67852514741464*^9}, {3.678532978061008*^9, 3.6785329787233057`*^9}, {
   3.6785330237944*^9, 3.678533053696352*^9}, {3.678533107601981*^9, 
   3.6785331303931513`*^9}, {3.678533218658008*^9, 3.678533219817922*^9}, {
   3.6785357605255003`*^9, 3.678535763986184*^9}, {3.678538383399919*^9, 
   3.67853838446167*^9}, 3.6786985371605597`*^9}],

Cell["\<\
Absorption mode 2D lineshapes are generated by using States or TPPI data \
acquisition or processing. In this case we get absorption-mode lineshapes.\
\>", "Text",
 CellChangeTimes->{{3.678533259702269*^9, 3.6785333222311487`*^9}, {
   3.678533453027628*^9, 3.678533461304871*^9}, {3.6785350700486*^9, 
   3.6785350817656393`*^9}, 3.678698665063637*^9}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", 
       RowBox[{"peaks", ",", 
        RowBox[{"Symmetrize", "\[Rule]", "True"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", 
     RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", 
     RowBox[{"-", "100"}], ",", "100"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678524642317128*^9, 3.678524664601783*^9}, {
  3.678524854560987*^9, 3.678524878492941*^9}, {3.6785251455923157`*^9, 
  3.67852514741464*^9}, {3.678532978061008*^9, 3.6785329787233057`*^9}, {
  3.6785330237944*^9, 3.678533053696352*^9}, {3.678533107601981*^9, 
  3.6785331303931513`*^9}, {3.678533218658008*^9, 3.678533219817922*^9}, {
  3.6785357605255003`*^9, 3.678535763986184*^9}, {3.678538383399919*^9, 
  3.67853838446167*^9}, {3.6786985371605597`*^9, 3.678698558410322*^9}}],

Cell["plot slice through 2D spectrum", "Text",
 CellChangeTimes->{{3.678698627362908*^9, 3.678698632402162*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", 
       RowBox[{"peaks", ",", 
        RowBox[{"Symmetrize", "\[Rule]", "True"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "50"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", 
     RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6786985888190327`*^9, 3.678698622682539*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["COSY in an AB spin system", "Subsection",
 CellChangeTimes->{{3.678535150699234*^9, 3.678535155146798*^9}, {
  3.67853521436414*^9, 3.678535214913518*^9}, {3.6786991293007812`*^9, 
  3.6786991412315903`*^9}}],

Cell[CellGroupData[{

Cell["setup", "Subsubsection",
 CellChangeTimes->{{3.6786984592282057`*^9, 3.6786984830676327`*^9}}],

Cell["\<\
Specify an additional offset in order to prevent spectral overlap\
\>", "Text",
 CellChangeTimes->{{3.678535719777687*^9, 3.678535737176238*^9}, {
  3.67869877875697*^9, 3.678698780972282*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SetSpinSystem", "[", "2", "]"}]}], "Input",
 CellChangeTimes->{{3.678530076322297*^9, 3.6785300829884043`*^9}, {
  3.678530117852811*^9, 3.678530122532709*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.678530123150388*^9, 3.678532054248698*^9, 
  3.678534179784376*^9, 3.678538139886883*^9, 3.678698067427342*^9, 
  3.678698720980433*^9, 3.678698767916772*^9, 3.678699400993181*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parameters", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[CapitalOmega]1", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "60"}]}], ",", " ", 
    RowBox[{"\[CapitalOmega]2", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", 
      RowBox[{"(", 
       RowBox[{"-", "10"}], ")"}]}]}], ",", " ", 
    RowBox[{"J", "\[Rule]", "20"}], ",", " ", 
    RowBox[{"offset", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "100"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.678530141839306*^9, 3.678530190341776*^9}, {
  3.67853038673897*^9, 3.678530401591988*^9}, {3.678533151617073*^9, 
  3.678533169396323*^9}, {3.6786987528595123`*^9, 3.678698760530818*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalOmega]1", "\[Rule]", 
    RowBox[{"120", " ", "\[Pi]"}]}], ",", 
   RowBox[{"\[CapitalOmega]2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "20"}], " ", "\[Pi]"}]}], ",", 
   RowBox[{"J", "\[Rule]", "20"}], ",", 
   RowBox[{"offset", "\[Rule]", 
    RowBox[{"200", " ", "\[Pi]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.678530190919232*^9, {3.678530387321327*^9, 3.678530409732147*^9}, 
   3.6785320545887403`*^9, {3.678533153005501*^9, 3.678533172777575*^9}, 
   3.678534189120825*^9, 3.678538140041078*^9, 3.678698072215176*^9, 
   3.678698721008765*^9, {3.6786987619309*^9, 3.6786987679515457`*^9}, 
   3.678699401031851*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"H0", "[", "opts___Rule", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalOmega]1", " ", 
        RowBox[{"opI", "[", 
         RowBox[{"1", ",", "\"\<z\>\""}], "]"}]}], "+", 
       RowBox[{"\[CapitalOmega]2", " ", 
        RowBox[{"opI", "[", 
         RowBox[{"2", ",", "\"\<z\>\""}], "]"}]}], "+", 
       RowBox[{"2", "\[Pi]", " ", "J", " ", 
        RowBox[{
         RowBox[{"opI", "[", "1", "]"}], ".", 
         RowBox[{"opI", "[", "2", "]"}]}]}], "+", 
       RowBox[{"offset", " ", 
        RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]}], ")"}], "/.", 
     RowBox[{"{", "opts", "}"}]}], "/.", "parameters"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6785301257172623`*^9, 3.678530126691823*^9}, {
  3.678530194829555*^9, 3.67853030976906*^9}, {3.678698738246759*^9, 
  3.6786987446014433`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H0", "[", "]"}]], "Input",
 CellChangeTimes->{{3.678530312313595*^9, 3.678530313538426*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"40", " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "x"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "x"}]],
        DisplayForm]}],
      DisplayForm], "+", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "y"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "y"}]],
        DisplayForm]}],
      DisplayForm], "+", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "z"}]],
        DisplayForm]}],
      DisplayForm]}], ")"}]}], "+", 
  RowBox[{"120", " ", "\[Pi]", " ", 
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm]}], "-", 
  RowBox[{"20", " ", "\[Pi]", " ", 
   TagBox[
    SubscriptBox["I", 
     RowBox[{"2", "z"}]],
    DisplayForm]}], "+", 
  RowBox[{"200", " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     TagBox[
      SubscriptBox["I", 
       RowBox[{"1", "z"}]],
      DisplayForm], "+", 
     TagBox[
      SubscriptBox["I", 
       RowBox[{"2", "z"}]],
      DisplayForm]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.678530314069179*^9, 3.6785304098138027`*^9, 3.678532054662485*^9, {
   3.678533157606947*^9, 3.6785331728351603`*^9}, 3.6785341922233067`*^9, 
   3.6785381401092043`*^9, 3.678698072307716*^9, {3.678698721046414*^9, 
   3.678698767984993*^9}, 3.6786994010656843`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D spectrum", "Subsubsection",
 CellChangeTimes->{{3.6786984592282057`*^9, 3.6786984830676327`*^9}, {
  3.67869879252756*^9, 3.678698795935107*^9}, {3.6786991268726587`*^9, 
  3.678699127365896*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Rho]ini", "=", 
   RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Exc", "=", 
   RowBox[{"RotationSuperoperator", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<x\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mix", "=", 
   RowBox[{"RotationSuperoperator", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<x\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qobs", "=", 
   RowBox[{
    RowBox[{"-", "2"}], "I", "  ", 
    RowBox[{"opI", "[", "\"\<-\>\"", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"peaks", "=", 
  RowBox[{"Peaks2D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Rho]ini", ",", "Exc", ",", "Mix", ",", "Qobs"}], "}"}], ",", 
    RowBox[{"H0", "[", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.678534229826165*^9, 3.6785343151928387`*^9}, {
   3.6785343858768663`*^9, 3.678534397795134*^9}, 3.678534500810471*^9, {
   3.678534653302196*^9, 3.678534673492441*^9}, {3.678534796293148*^9, 
   3.6785348072113533`*^9}, {3.678534936547591*^9, 3.6785350265767193`*^9}, {
   3.678535226370846*^9, 3.678535234361498*^9}, 3.678535279398363*^9, 
   3.678535352603569*^9, {3.678535416590843*^9, 3.678535421950673*^9}, {
   3.678698799671281*^9, 3.678698802989389*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CheckBasis", "::", "orthonormal"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"State basis is orthonormal.\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{{3.6785342977848253`*^9, 3.6785343160698547`*^9}, 
   3.678534361131515*^9, 3.678534398725758*^9, 3.67853446437127*^9, 
   3.678534501826726*^9, {3.678534624808826*^9, 3.678534674049464*^9}, 
   3.6785347146786413`*^9, {3.678534782345335*^9, 3.6785348080590553`*^9}, 
   3.678535019760504*^9, 3.678535240325576*^9, 3.67853528035365*^9, 
   3.6785353536965437`*^9, 3.678535422822617*^9, 3.678538403568132*^9, 
   3.6786988041840897`*^9, 3.678699401347281*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1076.941413924145`"}], ",", "493.8549128707515`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169806`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1076.941413924145`"}], ",", "951.2777077805531`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1315073605796129`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1076.941413924145`"}], ",", "1076.941413924145`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169815`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1076.941413924145`"}], ",", "619.5186190143434`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.2311320754716981`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "619.5186190143434`"}], ",", "493.8549128707515`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169798`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "619.5186190143434`"}], ",", "951.2777077805531`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169815`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "619.5186190143434`"}], ",", "1076.941413924145`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.40622848847699106`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "619.5186190143434`"}], ",", "619.5186190143434`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"493.8549128707515`", ",", "493.8549128707515`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169806`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"493.8549128707515`", ",", "951.2777077805531`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.1315073605796129`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"493.8549128707515`", ",", "1076.941413924145`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"493.8549128707515`", ",", "619.5186190143434`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.2311320754716981`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"951.2777077805531`", ",", "493.8549128707515`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169798`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"951.2777077805531`", ",", "951.2777077805531`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"951.2777077805531`", ",", "1076.941413924145`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.40622848847699106`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"951.2777077805531`", ",", "619.5186190143434`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.1315073605796129`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1076.941413924145`", ",", "493.8549128707515`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1076.941413924145`", ",", "951.2777077805531`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1076.941413924145`", ",", "1076.941413924145`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169806`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1076.941413924145`", ",", "619.5186190143434`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1315073605796129`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "493.8549128707515`"}], ",", "493.8549128707515`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169815`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "493.8549128707515`"}], ",", "951.2777077805531`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "493.8549128707515`"}], ",", "1076.941413924145`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169806`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "493.8549128707515`"}], ",", "619.5186190143434`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169815`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"619.5186190143434`", ",", "493.8549128707515`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.40622848847699106`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"619.5186190143434`", ",", "951.2777077805531`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.2311320754716981`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"619.5186190143434`", ",", "1076.941413924145`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169798`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"619.5186190143434`", ",", "619.5186190143434`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.23113207547169815`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "951.2777077805531`"}], ",", "493.8549128707515`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.40622848847699106`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "951.2777077805531`"}], ",", "951.2777077805531`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.2311320754716981`"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "951.2777077805531`"}], ",", "1076.941413924145`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.23113207547169798`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "951.2777077805531`"}], ",", "619.5186190143434`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.678534298303314*^9, 3.678534316620743*^9}, 
   3.678534361538315*^9, 3.678534399135789*^9, 3.678534464778421*^9, 
   3.678534502226513*^9, {3.678534625393993*^9, 3.678534674599235*^9}, 
   3.678534715497238*^9, {3.67853478307686*^9, 3.6785348088037977`*^9}, 
   3.678535020475525*^9, 3.678535241099916*^9, 3.678535281131084*^9, 
   3.6785353544696627`*^9, 3.678535423937632*^9, 3.67853840471034*^9, 
   3.678698805476288*^9, 3.678699402251267*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.678535244815624*^9, 3.678535247309417*^9}}],

Cell[BoxData["32"], "Output",
 CellChangeTimes->{3.678535247786128*^9, 3.678535430593946*^9, 
  3.678538409395854*^9, 3.6786994022999783`*^9}]
}, Open  ]],

Cell["\<\
This shows there are 32 peaks in the 2D spectrum. These have phase-twist \
lineshapes. \
\>", "Text",
 CellChangeTimes->{{3.6785350317669783`*^9, 3.6785350559024687`*^9}, {
  3.678535434086774*^9, 3.678535434245612*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", "peaks", "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", 
     RowBox[{"-", "250"}], ",", "250"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", "0", ",", "250"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678524642317128*^9, 3.678524664601783*^9}, {
   3.678524854560987*^9, 3.678524878492941*^9}, {3.6785251455923157`*^9, 
   3.67852514741464*^9}, {3.678532978061008*^9, 3.6785329787233057`*^9}, {
   3.6785330237944*^9, 3.678533053696352*^9}, {3.678533107601981*^9, 
   3.6785331303931513`*^9}, {3.678533218658008*^9, 3.678533219817922*^9}, {
   3.6785354472296467`*^9, 3.678535451843177*^9}, {3.6785354830225897`*^9, 
   3.678535534691824*^9}, {3.678535702387251*^9, 3.6785357026987743`*^9}, 
   3.6785384142607193`*^9, {3.67869881597269*^9, 3.6786988189477158`*^9}}],

Cell["STATES/TPPI processing:", "Text",
 CellChangeTimes->{{3.678535547227293*^9, 3.6785355551470947`*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"Spectrum2D", "[", 
       RowBox[{"peaks", ",", 
        RowBox[{"Symmetrize", "\[Rule]", "True"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
       RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]1", ",", "0", ",", "250"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", "0", ",", "250"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.678524642317128*^9, 3.678524664601783*^9}, {
   3.678524854560987*^9, 3.678524878492941*^9}, {3.6785251455923157`*^9, 
   3.67852514741464*^9}, {3.678532978061008*^9, 3.6785329787233057`*^9}, {
   3.6785330237944*^9, 3.678533053696352*^9}, {3.678533107601981*^9, 
   3.6785331303931513`*^9}, {3.678533218658008*^9, 3.678533219817922*^9}, {
   3.6785354472296467`*^9, 3.678535451843177*^9}, {3.6785354830225897`*^9, 
   3.678535534691824*^9}, {3.678535702387251*^9, 3.6785357026987743`*^9}, 
   3.6785384142607193`*^9, {3.67869881597269*^9, 3.678698837201035*^9}, 
   3.678698904006308*^9}],

Cell["\<\
The cross-peaks are in absorption, while the diagonal peaks are in dispersion\
\
\>", "Text",
 CellChangeTimes->{{3.678698917639654*^9, 3.6786989322087383`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Evaluate", "@", 
      RowBox[{"Re", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Spectrum2D", "[", 
          RowBox[{"peaks", ",", 
           RowBox[{"Symmetrize", "\[Rule]", "True"}]}], "]"}], "[", 
         RowBox[{
          RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
          RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{"\[Nu]1", "\[Rule]", "171.4"}], "}"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Evaluate", "@", 
      RowBox[{"Re", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Spectrum2D", "[", 
          RowBox[{"peaks", ",", 
           RowBox[{"Symmetrize", "\[Rule]", "True"}]}], "]"}], "[", 
         RowBox[{
          RowBox[{"2", "\[Pi]", " ", "\[Nu]1"}], ",", 
          RowBox[{"2", "\[Pi]", " ", "\[Nu]2"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{"\[Nu]1", "\[Rule]", 
          RowBox[{"171.4", "+", "1"}]}], "}"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Nu]2", ",", "0", ",", "250"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Blue"}], "}"}]}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.678698951939386*^9, 3.678698971517825*^9}, {
  3.678699009905169*^9, 3.678699058582458*^9}, {3.678699088960849*^9, 
  3.678699091129182*^9}, {3.6786994283437147`*^9, 3.678699456670896*^9}, {
  3.6786995496902857`*^9, 3.678699577823601*^9}, {3.678699629901968*^9, 
  3.678699684588711*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{876, 807},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->"MHL-StyleSheet.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 392, 10, 49, "Text"],
Cell[CellGroupData[{
Cell[975, 34, 119, 1, 62, "Subchapter"],
Cell[CellGroupData[{
Cell[1119, 39, 144, 2, 28, "Input"],
Cell[1266, 43, 148, 4, 33, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1451, 52, 151, 2, 46, "Input"],
Cell[1605, 56, 252, 4, 28, "Output"],
Cell[1860, 62, 230, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2127, 70, 196, 2, 44, "Subsection"],
Cell[2326, 74, 611, 14, 50, "Text"],
Cell[2940, 90, 287, 8, 28, "Input"],
Cell[3230, 100, 1355, 35, 46, "Input"],
Cell[4588, 137, 847, 23, 28, "Input"],
Cell[5438, 162, 805, 22, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6280, 189, 226, 3, 36, "Subsection"],
Cell[6509, 194, 344, 6, 49, "Text"],
Cell[6856, 202, 440, 11, 28, "Input"],
Cell[7299, 215, 1574, 40, 131, "Input"],
Cell[8876, 257, 1268, 35, 131, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[10181, 297, 248, 4, 36, "Subsection"],
Cell[10432, 303, 606, 9, 87, "Text"],
Cell[11041, 314, 199, 4, 30, "Text"],
Cell[11243, 320, 186, 4, 30, "Text"],
Cell[11432, 326, 5507, 123, 403, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[16988, 455, 182, 2, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[17195, 461, 209, 3, 44, "Subsection"],
Cell[17407, 466, 599, 14, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[18043, 485, 317, 4, 36, "Subsection"],
Cell[18363, 491, 732, 20, 28, "Input"],
Cell[19098, 513, 1511, 38, 80, "Input"],
Cell[20612, 553, 1265, 35, 80, "Input"],
Cell[21880, 590, 1494, 38, 80, "Input"],
Cell[23377, 630, 1357, 36, 114, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[24771, 671, 221, 3, 36, "Subsection"],
Cell[CellGroupData[{
Cell[25017, 678, 100, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[25142, 683, 267, 5, 46, "Input"],
Cell[25412, 690, 660, 13, 40, "Message"],
Cell[26075, 705, 801, 15, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26913, 725, 534, 13, 28, "Input"],
Cell[27450, 740, 568, 13, 28, "Output"]
}, Open  ]],
Cell[28033, 756, 760, 20, 28, "Input"],
Cell[CellGroupData[{
Cell[28818, 780, 116, 2, 28, "Input"],
Cell[28937, 784, 1583, 58, 35, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[30569, 848, 106, 1, 29, "Subsubsection"],
Cell[CellGroupData[{
Cell[30700, 853, 457, 13, 28, "Input"],
Cell[31160, 868, 950, 17, 40, "Message"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32159, 891, 166, 2, 35, "Subsubsection"],
Cell[32328, 895, 219, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[32572, 904, 225, 6, 28, "Input"],
Cell[32800, 912, 300, 5, 48, "Output"]
}, Open  ]],
Cell[33115, 920, 144, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[33284, 925, 1901, 51, 148, "Input"],
Cell[35188, 978, 299, 7, 21, "Message"],
Cell[35490, 987, 2756, 73, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38283, 1065, 126, 2, 28, "Input"],
Cell[38412, 1069, 143, 2, 28, "Output"]
}, Open  ]],
Cell[38570, 1074, 180, 4, 30, "Text"],
Cell[38753, 1080, 1081, 24, 80, "Input"],
Cell[39837, 1106, 363, 6, 49, "Text"],
Cell[40203, 1114, 1174, 26, 80, "Input"],
Cell[41380, 1142, 112, 1, 30, "Text"],
Cell[41495, 1145, 607, 16, 46, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42151, 1167, 214, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[42390, 1174, 100, 1, 35, "Subsubsection"],
Cell[42493, 1177, 203, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[42721, 1185, 267, 5, 46, "Input"],
Cell[42991, 1192, 678, 13, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43706, 1210, 670, 15, 28, "Input"],
Cell[44379, 1227, 695, 16, 28, "Output"]
}, Open  ]],
Cell[45089, 1246, 898, 23, 46, "Input"],
Cell[CellGroupData[{
Cell[46012, 1273, 116, 2, 28, "Input"],
Cell[46131, 1277, 1871, 69, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48051, 1352, 205, 3, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[48281, 1359, 1414, 36, 97, "Input"],
Cell[49698, 1397, 662, 12, 21, "Message"],
Cell[50363, 1411, 9171, 265, 284, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59571, 1681, 125, 2, 28, "Input"],
Cell[59699, 1685, 142, 2, 28, "Output"]
}, Open  ]],
Cell[59856, 1690, 230, 5, 30, "Text"],
Cell[60089, 1697, 1160, 24, 80, "Input"],
Cell[61252, 1723, 107, 1, 30, "Text"],
Cell[61362, 1726, 1236, 26, 80, "Input"],
Cell[62601, 1754, 171, 4, 30, "Text"],
Cell[62775, 1760, 1810, 45, 131, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

